+++
title = "French verbs"
languageCode = "fr"
target-languages = [ "fr",]
+++

To an English speaker, the number of conjugations of French verbs can
look quite daunting. Fortunately, day to day language only requires a
limited number of them.

## Modes

French has several "modes" for verbs.

  - Infinitive: the form you find in dictionaries. It is roughly
    equivalent to the English infinitive (the "to work" form).
  - Indicative: used to indicate actual actions, whether past, present
    or future.
  - Conditional: simply put, the mode you'll use after an "if"
    statement. This mode indicates that something will happen under a
    certain condition.
  - Subjunctive: this is probably the trickiest mode. It is usually used
    to mark wish/will, judgement, necessity, etc...
  - Imperative: as in English, this is the mode to give orders.

## Indicative tenses

The indicative mode boasts 8 different tenses, but not all are commonly
used in conversation.

Here is a short summary of each of them:

  - présent: the present tense is used as an equivalent to both the
    English *present simple* and *present continuous*. It can be used to
    indicate:
      - an action currently happening: *je marche* - I am walking.
      - general truth: *un jour dure 24h* - a day lasts 24h.
      - an action repeated regularly: *je mange à midi* - I eat at noon.

<!-- end list -->

  - imparfait: used to indicate:
      - actions that last in the past: Quand *j'étais* étudiant, je
        *travaillais* beaucoup. - When I was a student, I was working a
        lot (or: I used to work a lot). (Note that this sentence does
        not necessarily imply anything for the present situation of the
        speaker, he may or may not still be working a lot)
      - simultaneous actions in the past: Quand je l'ai vu, il
        *marchait* dans la rue. - When I saw him, he was walking in the
        street.
      - descriptions in the past tense: Il *pleuvait*. - It was raining.
        Elles *avaient* 30 ans. - They were 30 years old...

<!-- end list -->

  - passé composé: the most commonly used tense for verbs in the past in
    spoken French. It can indicate:
      - a brief action: Hier, je *suis allé* à l'école. - Yesterday, I
        went to school.
      - a repeated action: Ton ami *a téléphoné* 4 fois. - Your friend
        called 4 times.
      - a series of short actions: Il *a acheté* le journal, *s'est
        assis* sur un banc et *a lu* pendant une heure. - He bought the
        newspaper, sat on a bench and read for an hour.
      - an action with a certain duration in the past, but now finished:
        Nous *avons vécu* à Lyon pendant 3 ans. - We lived in Lyon for 3
        years. It is roughly equivalent to passé simple, but used both
        in spoken and written language. In writing, it is a lot less
        formal than passé simple.

<!-- end list -->

  - futur simple or futur: equivalent to the English *will + verb*. It
    indicates actions that will happen in the future.
      - example: Demain, nous *irons* nous promener.
      - It can often be replaced by *aller + infinitive*, especially in
        the spoken language: Elle *va venir* la semaine prochaine. -
        (this is very similar to the English construct: She's going to
        come next week.)
      - for actions that are just about to happen, futur simple is
        replaced with présent: J'*arrive* tout de suite. - I'm coming
        right away.

<!-- end list -->

  - passé simple: It is mostly used in formal written French. It sounds
    very formal in speech, where passé composé is used instead (see
    above). In writing, it indicates:
      - sudden/short actions: Il *sortit* - he left.
      - actions with a limited duration: Elle *dirigea* la société
        pendant 4 ans. - She led the company for 4 years.
      - actions repeated a limited number of times: Elles *visitèrent*
        Paris quelques fois. - They visited Paris a few times.

<!-- end list -->

  - plus-que-parfait: a past tense, mostly used for the *concordance des
    temps* in the past. It can indicate:
      - one or more completed actions prior to another action in the
        past: Il *avait terminé* son repas quand elle arriva/est
        arrivée. - He had finished his meal when she arrived.
      - an action that was started prior to another one in the past, but
        still ongoing when the second happened: Elle *avait disparu*
        depuis 3 jours lorsque la police l'a retrouvée.

<!-- end list -->

  - passé antérieur: It is formed with the passé simple + participe
    passé. Rarely used in modern French, this tense belongs to formal
    language. It can be used:
      - to show that an action happened just before another one in the
        past. The verb will then follow *après que, dès que, lorsque,
        quand* in a subordinate proposition: Dès que le soleil se fut
        couché, ils se mirent en route. - As soon as the sun set, they
        set off.
      - in a fairly rare construct to show the consequence of an action
        in the past, it is then used with *tôt, vite, bientôt...*: Elle
        *eut* vite *fait* de comprendre ce qui se passait. - She quickly
        understood what was going on. (in spoken French, you will mostly
        hear passé composé instead: Elle *a* vite *fait* de comprendre
        ce qui se passait.)

<!-- end list -->

  - futur antérieur: used to indicate that an action will happen before
    another one in the future.

## Irregular verbs

Many common verbs are irregular.

  - être: to be ([conjugations](/fr/Etre_conjugations))
  - avoir: to have ([conjugations](/fr/Avoir_conjugations))

## Regular verbs

French regular verbs are split in 3 groups:

  - First group: verbs whose infinitive ends in "-er" (except
    "[aller](/fr/Aller_conjugations)"). They are conjugated like
    [marcher](/fr/Marcher_conjugations).
  - Second group: verbs whose infinitive ends in "-ir". The typical
    example is ["finir"](/fr/Finir_conjugations) (to finish).
  - Third group: everything else, with infinitives usually ending in
    "-re" or "-oir", but not exclusively. Examples of common verbs
    include: "[aller](/fr/Aller_conjugations)"
